@@ -43,6 +43,20 @@
 		* ERROR:  -
 		*/
 		public static function valid_address($email) {
+			$forbidden = array("10minutemail.com", "burnthespam.info", "deadaddress.com", "e4ward.com",
+				"eyepaste.com", "armyspy.com", "cuvox.de", "dayrep.com", "einrot.com", "fleckens.hu",
+				"gustr.com", "jourrapide.com", "rhyta.com", "superrito.com", "teleworm.us", "filzmail.com",
+				"getairmail.com", "gishpuppy.com", "guerrillamail.com", "incognitomail.org", "jetable.org",
+				"mailcatch.com", "mailexpire.com", "mailinator.com", "mailmoat.com", "meltmail.com",
+				"trbvm.com", "temp-mail.org", "mt2014.com", "mytrashmail.com", "trashymail.com",
+				"no-spam.ws", "onewaymail.com", "shitmail.org", "crapmail.org", "spambox.us",
+				"spamgourmet.com", "tempemail.net", "yopmail.com");
+
+			list(, $domain) = explode("@", $email, 2);
+			if (in_array(strtolower($domain), $forbidden)) {
+				return false;
+			}
+
 			return preg_match("/^[0-9A-Za-z]([-_.~]?[0-9A-Za-z])*@[0-9A-Za-z]([-.]?[0-9A-Za-z])*\\.[A-Za-z]{2,4}$/", $email) === 1;
 		}
 
@@ -209,7 +223,7 @@
 			}
 
 			$content_type = mime_content_type($filename);
-			$content_id = sha1($image["content"]);
+			$content_id = sha1($content);
 
 			/* Add attachment
 			 */
@@ -268,8 +282,8 @@
 
 			if ($content_type == "text/plain") {
 				$message = str_replace("\n", "", $message);
-				$message = str_replace("</th><th>", "</th> | <th>", $message);
-				$message = str_replace("</td><td>", "</td> | <td>", $message);
+				$message = str_replace("</th><th>", "</th> <th>", $message);
+				$message = str_replace("</td><td>", "</td> <td>", $message);
 				$message = str_replace("</tr>", "</tr>\n", $message);
 				$message = str_replace("</table>", "</table>\n", $message);
 				$message = str_replace("<br>", "<br>\n", $message);
